@@ -2,10 +2,8 @@
 Packages extension
 ------------------
 """
-from __future__ import unicode_literals
 import os
-from six.moves.urllib.parse import urljoin
-from six import text_type
+from urllib.parse import urljoin
 
 from lxml.etree import tounicode, SubElement, Element
 from lxml.objectify import fromstring
@@ -105,7 +103,7 @@ class Package(ExtensionBase):
         :type meta: str or lxml.objectify.ObjectifiedElement
         :return:
         """
-        if isinstance(meta, text_type):
+        if isinstance(meta, (str, bytes)):
             meta = fromstring(meta)
 
         if meta is not None:
