@@ -2,10 +2,9 @@
 Projects extension
 ------------------
 """
-from __future__ import unicode_literals
 import re
-from six.moves.urllib.parse import urljoin
-from six import text_type
+from urllib.parse import urljoin
+from warnings import warn
 
 from lxml.etree import tounicode
 from lxml.objectify import fromstring, SubElement
@@ -15,8 +14,6 @@ from ..utils.base import ExtensionBase
 
 TEMPLATE_CREATE_ATTR = "<attributes><attribute namespace='' name=''></attribute></attributes>"
 TEMPLATE_META = "<project name=''><title></title><description></description>" \
-                "<person userid='' role='bugowner'/>" \
-                "<person userid='' role='maintainer'/>" \
                 "<build><enable/></build><publish><disable/></publish>" \
                 "<debuginfo><enable/></debuginfo></project>"
 
@@ -73,6 +70,33 @@ class Project(ExtensionBase):
 
         .. versionadded:: 0.1.5
 
+        .. deprecated:: 0.7.2
+           Use :meth:`set_meta` instead
+        :param project: name of project
+        :param metafile: Complete metafile
+        :type metafile: str or ElementTree
+        :param title: Title for meta file
+        :param description: Description for meta file
+        :param bugowner: Bugowner for meta file
+        :param maintainer: Maintainer for meta file
+        :return: ``True``, if successful. Otherwise API response
+        :rtype: bool or lxml.objectify.ObjectifiedElement
+        """
+        warn("Deprecated. Use projects.set_meta instead")
+
+        return self.set_meta(project, metafile, title, description, bugowner,
+                      maintainer)
+
+    # pylint: disable=too-many-arguments
+    def set_meta(self, project, metafile=None, title=None, description=None,
+                 bugowner=None, maintainer=None):
+        """
+        Edit project meta data or create a new project
+
+        If no ``metafile`` is provided, a default template is used.
+
+        .. versionadded:: 0.7.2
+
         :param project: name of project
         :param metafile: Complete metafile
         :type metafile: str or ElementTree
@@ -86,24 +110,34 @@ class Project(ExtensionBase):
         if metafile is None:
             metafile = TEMPLATE_META
 
-        if isinstance(metafile, text_type):
+        if isinstance(metafile, (str, bytes)):
             metafile = fromstring(metafile)
 
         metafile.set("name", project)
 
-        # pylint: disable=protected-access
-        if title:
-            metafile.title._setText(title)
-        if description:
-            metafile.description._setText(description)
+        for required_field, text in (('title', title), ('description', description)):
+            elem = metafile.find(required_field)
+            if elem is None:
+                elem = SubElement(metafile, required_field)
+
+            if text is not None:
+                # pylint: disable=protected-access
+                elem._setText(text)
+
+        def add_person(role: str, userid: str) -> None:
+            person = metafile.xpath(f"person[@role='{role}']")
+            if not person:
+                person = [SubElement(metafile, 'person', role=role)]
+            person[0].set("userid", userid)
+
         if bugowner:
-            person = metafile.xpath("person[@role='bugowner']")
-            if person:
-                person[0].set("userid", bugowner)
+            add_person("bugowner", bugowner)
+
         if maintainer:
-            person = metafile.xpath("person[@role='maintainer']")
-            if person:
-                person[0].set("userid", maintainer)
+            add_person("maintainer", maintainer)
+
+        metafile.insert(0, metafile.title)
+        metafile.insert(1, metafile.description)
 
         response = self.osc.request(
             url=urljoin(self.osc.url,
@@ -134,7 +168,7 @@ class Project(ExtensionBase):
         """
         kwargs["meta"] = meta
         if rev:
-            kwargs["rev"] = text_type(rev)
+            kwargs["rev"] = str(rev)
         response = self.osc.request(
             url=urljoin(
                 self.osc.url,
@@ -207,7 +241,7 @@ class Project(ExtensionBase):
         for val in value:
             elem = SubElement(attr_xml.attribute, "value")
             # pylint: disable=protected-access
-            elem._setText(text_type(val))
+            elem._setText(str(val))
 
         response = self.osc.request(
             url=url,
@@ -352,7 +386,7 @@ class Project(ExtensionBase):
         .. versionadded:: 0.1.2
 
         :param project: Project name
-        :return: ``True``, if package exists, otherwise ``False``
+        :return: ``True``, if project exists, otherwise ``False``
         """
         response = self.osc.request(
             url=urljoin(
@@ -365,4 +399,4 @@ class Project(ExtensionBase):
 
         return response.status_code == 200
 
-    create = put_meta
+    create = set_meta
