@@ -129,7 +129,7 @@ class Osc:
     default_connection_retries = 5
     default_retry_timeout = 5
 
-    def __init__(self, url: str = None, username: typing.Optional[str] = None,
+    def __init__(self, url: typing.Optional[str] = None, username: typing.Optional[str] = None,
                  password: typing.Optional[str] = None, verify: typing.Optional[str] = None,
                  cache: bool = False,
                  ssh_key_file: typing.Optional[typing.Union[Path, str]] = None):
@@ -341,7 +341,9 @@ class Osc:
                 logger.info("Server replied with status %d", response.status_code)
                 logger.debug("Response headers:\n%s\n---",
                              "\n".join(f"{k}: {v}" for k, v in response.headers.items()))
-                logger.debug("Response content:\n%s\n---", response.text)
+                if not stream:
+                    # The response content must not be accessed when streaming
+                    logger.debug("Response content:\n%s\n---", response.text)
                 if raise_for_status:
                     response.raise_for_status()
                 return response
@@ -394,8 +396,6 @@ class Osc:
         unexpected_bools = {key for key, value in params.items()
                             if isinstance(value, bool) and key not in BOOLEAN_PARAMS}
         if unexpected_bools:
-            warnings.warn(f"Received boolean query params, which are not expected to be: "
-                          f"{', '.join(unexpected_bools)}")
             for key in unexpected_bools:
                 params[key] = '1' if params[key] else '0'
 
